Search OCaml packages
max) { row = max } }" @keyup.up="if (row !== null) { row -=1; if (row < 0) { row = null } }" @keyup.right="if (col < 1) col++" @keyup.left="if (col >= 1) col--" :aria-activedescendant="row !== null ? 'package-autocomplete-'+row+'-'+col : null" hx-get="/packages/autocomplete" hx-params="q" hx-trigger="keyup changed, search" hx-target="#header-search-results" hx-indicator="#header-search-indicator" autocomplete="off" >
Standard Library API
Learn
Tools
Packages
Community
News
Play
Search OCaml packages
Learn
Tools
Packages
Community
News
Play
Standard Library API
Get started
package
h1
latest (1.1.1)
1.1.1
1.1.0
1.0.0
search
Overview
Docs
You can search for identifiers within the package.
in-package search v0.2.0
sectionYPositions = computeSectionYPositions($el), 10)" x-init="setTimeout(() => sectionYPositions = computeSectionYPositions($el), 10)" >
On This Page
v1.1.0
v1.0.0
package h1
h1
CHANGES
README
Library
h1
H1
Version
Method
Status
Headers
Body
Reader
Writer
Request
Body_length
Response
Body_length
IOVec
Reqd
Config
Server_connection
Client_connection
H1_private
Parse
Serialize
Sources
h1
body.ml
client_connection.ml
config.ml
h1.ml
h1__.ml
message.ml
optional_thunk.ml
parse.ml
reqd.ml
request.ml
response.ml
serialize.ml
server_connection.ml
websocket.ml
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Package index
h1
CHANGES
v1.1.1
Fix a bug on websocket frames and how we get the length of a frame (@dinosaure, #19)
v1.1.0
Add the websocket implementation (@swrup, @dinosaure, #8)
Fix last references of http/af (@dinosaure, @vlog, #13, #14, #16)
Fix the upgrade support and allow multiple values (@dinosaure, #15)
Move to
bstr
(@swrup, #11)
v1.0.0
First release of h1
sectionYPositions = computeSectionYPositions($el), 10)" x-init="setTimeout(() => sectionYPositions = computeSectionYPositions($el), 10)" >
On This Page
v1.1.0
v1.0.0